==> varsnap-0.1.1.tgz: package/README.md <==
varsnap.js
==========

[![Codeship Status for albertyw/varsnap.js](https://app.codeship.com/projects/772d6dd0-7616-0137-b181-4a74f06c083c/status?branch=master)](https://app.codeship.com/projects/349777)

https://www.varsnap.com/

Javascript VarSnap

Installation
------------

Install from NPM - `npm install --save varsnap`

Requirements
------------

This client is designed to work in both node.js and in the browser.  When
running in the node, these environment variables must be exported:

 - `varsnap` - Should be either `true` or `false`.  Varsnap will be disabled if the variable is anything other than `true`.
 - `env` - If set to `development`, the client will receive events from production.  If set to `production`, the client will emit events.
 - `varsnapProducerToken` - Only clients with this token may emit production snapshots.  Copied from https://www.varsnap.com/user/
 - `varsnapConsumerToken` - Only clients with this token may emit development snapshots.  Copied from https://www.varsnap.com/user/

When running in the browser, the same variables are read from a `varsnap` object under `window`, e.g.

```javascript
window.varsnap = {
  varsnap: 'true',
  env: 'production',
  varsnapProducerToken: 'producer-abcdefg',
};
```

Usage
-----

Wrap your functions with the varsnap decorator for any function you'd like to make better:

```javascript
const varsnap = require('varsnap');

function example(x, y, z) {
  // ...
}
example = varsnap(example);
example(1, 2, 3);
```

See `example.js` for example usage.

Publishing
----------

```bash
npm publish
```

==> varsnap-0.2.0.tgz: package/README.md <==
varsnap.js
==========

[![Codeship Status for albertyw/varsnap.js](https://app.codeship.com/projects/772d6dd0-7616-0137-b181-4a74f06c083c/status?branch=master)](https://app.codeship.com/projects/349777)

https://www.varsnap.com/

Javascript VarSnap Client.  For use in both browser and node.js

Installation
------------

Install from NPM - `npm install --save varsnap`

Requirements
------------

### Node.js

When running in the node, these environment variables must be exported:

 - `varsnap` - Should be either `true` or `false`.  Varsnap will be disabled if the variable is anything other than `true`.
 - `env` - If set to `development`, the client will receive events from production.  If set to `production`, the client will emit events.
 - `varsnapProducerToken` - Only clients with this token may emit production snapshots.  Copied from https://www.varsnap.com/user/
 - `varsnapConsumerToken` - Only clients with this token may emit development snapshots.  Copied from https://www.varsnap.com/user/


### Browser

When running in the browser, the same variables are read from a `varsnapConfig` object under `window`, e.g.

```javascript
window.varsnapConfig = {
  varsnap: 'true',
  env: 'production',
  varsnapProducerToken: 'producer-abcdefg',
};
```

Usage
-----

Wrap your functions with the varsnap decorator for any function you'd like to make better:

```javascript
// Node.js
var varsnap = require('varsnap');

// Browser
var varsnap = window.varsnap;

function example(x, y, z) {
  // ...
}
example = varsnap(example);
example(1, 2, 3);
```

See `example.js` for example usage.

Release
-------

1.  Update Changelog with new version
2.  Update `const version` in `core.js`
3.  Update package.json version and run `npm install`
4.  Update `.uglify.json` and `.uglify.min.json`
5.  Git commit and tag
6.  `npm publish`
7.  Upload `dist/*` to https://github.com/albertyw/varsnap.js/releases
